==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/ScatterLineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeriesView, _super);
    function ScatterLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dl = new Path();
        _this.dk = new Path();
        return _this;
    }
    ScatterLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.w1 = Defaults.e;
        }
    };
    ScatterLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    ScatterLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dk.an = this.dl.an;
        this.dk._stroke = a;
        this.dk.ad = this.e.ic + 3;
    };
    ScatterLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dk);
            }
            else {
                a.t(this.dl);
            }
        }
    };
    ScatterLineSeriesView.prototype.c9 = function (a) {
        _super.prototype.c9.call(this, a);
        this.dl.an = null;
        this.dk.an = null;
    };
    ScatterLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bb.exportPathData(a, this.dl, "shape", ["Main"]);
    };
    ScatterLineSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.vu = a;
        this.e.jk = 3;
        this.e.jl = 1;
        this.e.jm = 4;
        this.e.ha = false;
    };
    ScatterLineSeriesView.$t = markType(ScatterLineSeriesView, 'ScatterLineSeriesView', ScatterBaseView.$);
    return ScatterLineSeriesView;
}(ScatterBaseView));
export { ScatterLineSeriesView };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/ScatterLineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeriesView, _super);
    function ScatterLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dl = new Path();
        _this.dk = new Path();
        return _this;
    }
    ScatterLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.xa = Defaults.e;
        }
    };
    ScatterLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    ScatterLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dk.an = this.dl.an;
        this.dk._stroke = a;
        this.dk.ad = this.e.ie + 3;
    };
    ScatterLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dk);
            }
            else {
                a.t(this.dl);
            }
        }
    };
    ScatterLineSeriesView.prototype.c9 = function (a) {
        _super.prototype.c9.call(this, a);
        this.dl.an = null;
        this.dk.an = null;
    };
    ScatterLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bc.exportPathData(a, this.dl, "shape", ["Main"]);
    };
    ScatterLineSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.v1 = a;
        this.e.jm = 3;
        this.e.jn = 1;
        this.e.jo = 4;
        this.e.hc = false;
    };
    ScatterLineSeriesView.$t = markType(ScatterLineSeriesView, 'ScatterLineSeriesView', ScatterBaseView.$);
    return ScatterLineSeriesView;
}(ScatterBaseView));
export { ScatterLineSeriesView };
